#line 2 "align/phylipil.c"

#line 4 "align/phylipil.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer phylipi_create_buffer
#define yy_delete_buffer phylipi_delete_buffer
#define yy_flex_debug phylipi_flex_debug
#define yy_init_buffer phylipi_init_buffer
#define yy_flush_buffer phylipi_flush_buffer
#define yy_load_buffer_state phylipi_load_buffer_state
#define yy_switch_to_buffer phylipi_switch_to_buffer
#define yyin phylipiin
#define yyleng phylipileng
#define yylex phylipilex
#define yylineno phylipilineno
#define yyout phylipiout
#define yyrestart phylipirestart
#define yytext phylipitext
#define yywrap phylipiwrap
#define yyalloc phylipialloc
#define yyrealloc phylipirealloc
#define yyfree phylipifree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#ifdef _LIBC
#include "namespace.h"
#endif
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/*	$NetBSD: flexint.h,v 1.1.1.1 2009/10/26 00:26:19 christos Exp $	*/

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE phylipirestart(phylipiin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int phylipileng;

extern FILE *phylipiin, *phylipiout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up phylipitext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up phylipitext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via phylipirestart()), so that the user can continue scanning by
	 * just pointing phylipiin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when phylipitext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int phylipileng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow phylipiwrap()'s to do buffer switches
 * instead of setting up a fresh phylipiin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void phylipirestart (FILE *input_file  );
void phylipi_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE phylipi_create_buffer (FILE *file,int size  );
void phylipi_delete_buffer (YY_BUFFER_STATE b  );
void phylipi_flush_buffer (YY_BUFFER_STATE b  );
void phylipipush_buffer_state (YY_BUFFER_STATE new_buffer  );
void phylipipop_buffer_state (void );

static void phylipiensure_buffer_stack (void );
static void phylipi_load_buffer_state (void );
static void phylipi_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER phylipi_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE phylipi_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE phylipi_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE phylipi_scan_bytes (yyconst char *bytes,int len  );

void *phylipialloc (yy_size_t  );
void *phylipirealloc (void *,yy_size_t  );
void phylipifree (void *  );

#define yy_new_buffer phylipi_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        phylipiensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            phylipi_create_buffer(phylipiin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        phylipiensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            phylipi_create_buffer(phylipiin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define phylipiwrap(n) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *phylipiin = (FILE *) 0, *phylipiout = (FILE *) 0;

typedef int yy_state_type;

extern int phylipilineno;

int phylipilineno = 1;

extern char *phylipitext;
#define yytext_ptr phylipitext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up phylipitext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	phylipileng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 21
#define YY_END_OF_BUFFER 22
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[161] =
    {   0,
    16386,   22,   20,   21,   19,   21,   20,   21,16386,    1,
       19,   21,   20,   21,    8,   21,    4,    8,   21,    7,
       21,    3,    8,   21,   13,   21,   11,   13,   21,   12,
       21,   10,   13,   21,   10,   13,   21,   13,   21,   11,
       13,   21,   12,   21,   10,   13,   21,   10,   13,   21,
       18,   21,   16,   18,   21,   17,   21,   15,   18,   21,
       15,   18,   21,16386,    1,    4,    5,    6,    3,   11,
       10,   10,   11,   14,   14,   10,   10,   16,   15,   15,
     8194,    6,   10,   10,   11,   14,   14,   10,   10,   15,
       15,   10,   10,   11,   14,   14,   10,   10,   15,   15,

       10,   10,   11,   14,   14,   10,   10,   15,   15,   10,
       10,   11,   14,   14,   10,   10,   15,   15,   10,   10,
       11,   14,   14,   10,   10,   15,   15,   10,   10,   11,
       14,   14,   10,   10,   15,   15,   10,   10,   11,   14,
       14,   10,   10,   15,   15,   10,   10,    9,    9,   11,
       14,   14,    9,   10,    9,   10,   15,   15,   14,   14
    } ;

static yyconst flex_int16_t yy_accept[142] =
    {   0,
        1,    1,    2,    2,    2,    2,    2,    2,    2,    3,
        5,    7,   10,   13,   15,   17,   20,   22,   25,   27,
       30,   32,   35,   38,   40,   43,   45,   48,   51,   53,
       56,   58,   61,   64,   65,   66,   66,   66,   67,   69,
       69,   70,   71,   72,   73,   73,   74,   74,   75,   76,
       77,   78,   79,   80,   81,   82,   82,   83,   84,   85,
       85,   86,   87,   88,   89,   90,   91,   92,   93,   94,
       94,   95,   96,   97,   98,   99,  100,  101,  102,  103,
      103,  104,  105,  106,  107,  108,  109,  110,  111,  112,
      112,  113,  114,  115,  116,  117,  118,  119,  120,  121,

      121,  122,  123,  124,  125,  126,  127,  128,  129,  130,
      130,  131,  132,  133,  134,  135,  136,  137,  138,  139,
      139,  140,  141,  142,  143,  144,  145,  146,  147,  148,
      149,  151,  152,  153,  155,  157,  158,  159,  160,  161,
      161
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    1,    1,    1,    1,    4,
        4,    5,    1,    4,    6,    7,    1,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    4,    4,    1,
        1,    1,    9,    1,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
        4,    1,    4,    1,    1,    1,   10,   10,   10,   10,

       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,    1,    1,    1,   11,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[12] =
    {   0,
        1,    1,    2,    2,    1,    1,    1,    1,    1,    1,
        1
    } ;

static yyconst flex_int16_t yy_base[152] =
    {   0,
       79,    0,    7,   14,   22,   33,   44,    0,   77,  390,
      390,   54,  390,   61,  390,   68,  390,   68,  390,   73,
      390,   74,    0,    0,   72,   84,   95,    0,  390,   71,
      390,  102,    0,    0,  390,    0,   64,    0,  390,  112,
       60,   65,  118,    0,    0,   64,    0,  125,    0,  136,
        0,   63,  143,    0,   56,    0,  390,  150,    0,    0,
       59,  157,    0,  168,    0,  175,    0,  182,    0,    0,
       58,  189,    0,  200,    0,  207,    0,  214,    0,    0,
       57,  221,    0,  232,    0,  239,    0,  246,    0,    0,
       56,  253,    0,  264,    0,  271,    0,  278,    0,    0,

       19,  285,    0,  296,    0,  303,    0,  310,    0,    0,
       18,  317,    0,  328,    0,  335,    0,  342,    0,    0,
       17,  349,    0,  360,    0,  367,    0,  390,  390,  390,
       16,  374,    0,  390,  390,  390,  390,  390,  390,  390,
      385,  387,   13,   12,   11,   10,    6,    5,    4,    3,
        0
    } ;

static yyconst flex_int16_t yy_def[152] =
    {   0,
      141,  141,  142,  142,  140,  140,  140,    7,  140,  140,
      140,  140,  140,  140,  140,  140,  140,  140,  140,  140,
      140,  140,   22,  143,  143,  140,  140,   27,  140,  140,
      140,  140,   32,   12,  140,   14,   14,   16,  140,  140,
      140,  140,  140,   43,  144,  144,   26,  140,   48,  140,
       50,  140,  140,   53,  140,   40,  140,  140,   58,  145,
      145,  140,   62,  140,   64,  140,   66,  140,   68,  146,
      146,  140,   72,  140,   74,  140,   76,  140,   78,  147,
      147,  140,   82,  140,   84,  140,   86,  140,   88,  148,
      148,  140,   92,  140,   94,  140,   96,  140,   98,  149,

      149,  140,  102,  140,  104,  140,  106,  140,  108,  150,
      150,  140,  112,  140,  114,  140,  116,  140,  118,  151,
      151,  140,  122,  140,  124,  140,  126,  140,  140,  140,
      140,  140,  132,  140,  140,  140,  140,  140,  140,    0,
      140,  140,  140,  140,  140,  140,  140,  140,  140,  140,
      140
    } ;

static yyconst flex_int16_t yy_nxt[402] =
    {   0,
      130,   12,   13,  120,  110,  100,   90,   14,   16,   17,
       80,   70,   60,   45,   18,   16,   17,   42,  131,  121,
      111,   18,   19,   20,   21,   19,   22,   23,   23,   19,
       22,   22,   23,   24,   25,   26,   19,   27,   28,   28,
       24,   27,   27,   28,   29,   30,   31,   29,   32,   33,
       33,   29,   32,   32,   33,   34,   35,  101,   91,   81,
       71,   36,   37,   55,   52,   61,   42,   41,   36,   38,
       39,   55,   52,   46,   42,   41,  140,   40,   43,   44,
       44,   11,   43,   43,   44,   47,  140,  140,   48,   49,
       49,  140,   48,   48,   49,   45,   45,  140,  140,   50,

       51,   51,   45,   50,   50,   51,   53,   54,   54,  140,
       53,   53,   54,   56,   57,  140,  140,  140,  140,  140,
      140,   40,   58,   59,   59,  140,   58,   58,   59,   62,
       63,   63,  140,   62,   62,   63,   60,   60,  140,  140,
       64,   65,   65,   60,   64,   64,   65,   66,   67,   67,
      140,   66,   66,   67,   68,   69,   69,  140,   68,   68,
       69,   72,   73,   73,  140,   72,   72,   73,   70,   70,
      140,  140,   74,   75,   75,   70,   74,   74,   75,   76,
       77,   77,  140,   76,   76,   77,   78,   79,   79,  140,
       78,   78,   79,   82,   83,   83,  140,   82,   82,   83,

       80,   80,  140,  140,   84,   85,   85,   80,   84,   84,
       85,   86,   87,   87,  140,   86,   86,   87,   88,   89,
       89,  140,   88,   88,   89,   92,   93,   93,  140,   92,
       92,   93,   90,   90,  140,  140,   94,   95,   95,   90,
       94,   94,   95,   96,   97,   97,  140,   96,   96,   97,
       98,   99,   99,  140,   98,   98,   99,  102,  103,  103,
      140,  102,  102,  103,  100,  100,  140,  140,  104,  105,
      105,  100,  104,  104,  105,  106,  107,  107,  140,  106,
      106,  107,  108,  109,  109,  140,  108,  108,  109,  112,
      113,  113,  140,  112,  112,  113,  110,  110,  140,  140,

      114,  115,  115,  110,  114,  114,  115,  116,  117,  117,
      140,  116,  116,  117,  118,  119,  119,  140,  118,  118,
      119,  122,  123,  123,  140,  122,  122,  123,  120,  120,
      140,  140,  124,  125,  125,  120,  124,  124,  125,  126,
      127,  127,  140,  126,  126,  127,  128,  129,  129,  140,
      128,  128,  129,  132,  133,  133,  140,  132,  132,  133,
      130,  130,  140,  140,  134,  135,  135,  130,  134,  134,
      135,  136,  137,  137,  140,  136,  136,  137,  138,  139,
      139,  140,  138,  138,  139,   10,   10,   15,   15,    9,
      140,  140,  140,  140,  140,  140,  140,  140,  140,  140,

      140
    } ;

static yyconst flex_int16_t yy_chk[402] =
    {   0,
      151,    2,    2,  150,  149,  148,  147,    2,    3,    3,
      146,  145,  144,  143,    3,    4,    4,  131,  121,  111,
      101,    4,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,   12,   12,   91,   81,   71,
       61,   12,   14,   55,   52,   46,   42,   41,   14,   16,
       16,   37,   30,   25,   20,   18,    9,   16,   22,   22,
       22,    1,   22,   22,   22,   26,    0,    0,   26,   26,
       26,    0,   26,   26,   26,   27,   27,    0,    0,   27,

       27,   27,   27,   27,   27,   27,   32,   32,   32,    0,
       32,   32,   32,   40,   40,    0,    0,    0,    0,    0,
        0,   40,   43,   43,   43,    0,   43,   43,   43,   48,
       48,   48,    0,   48,   48,   48,   50,   50,    0,    0,
       50,   50,   50,   50,   50,   50,   50,   53,   53,   53,
        0,   53,   53,   53,   58,   58,   58,    0,   58,   58,
       58,   62,   62,   62,    0,   62,   62,   62,   64,   64,
        0,    0,   64,   64,   64,   64,   64,   64,   64,   66,
       66,   66,    0,   66,   66,   66,   68,   68,   68,    0,
       68,   68,   68,   72,   72,   72,    0,   72,   72,   72,

       74,   74,    0,    0,   74,   74,   74,   74,   74,   74,
       74,   76,   76,   76,    0,   76,   76,   76,   78,   78,
       78,    0,   78,   78,   78,   82,   82,   82,    0,   82,
       82,   82,   84,   84,    0,    0,   84,   84,   84,   84,
       84,   84,   84,   86,   86,   86,    0,   86,   86,   86,
       88,   88,   88,    0,   88,   88,   88,   92,   92,   92,
        0,   92,   92,   92,   94,   94,    0,    0,   94,   94,
       94,   94,   94,   94,   94,   96,   96,   96,    0,   96,
       96,   96,   98,   98,   98,    0,   98,   98,   98,  102,
      102,  102,    0,  102,  102,  102,  104,  104,    0,    0,

      104,  104,  104,  104,  104,  104,  104,  106,  106,  106,
        0,  106,  106,  106,  108,  108,  108,    0,  108,  108,
      108,  112,  112,  112,    0,  112,  112,  112,  114,  114,
        0,    0,  114,  114,  114,  114,  114,  114,  114,  116,
      116,  116,    0,  116,  116,  116,  118,  118,  118,    0,
      118,  118,  118,  122,  122,  122,    0,  122,  122,  122,
      124,  124,    0,    0,  124,  124,  124,  124,  124,  124,
      124,  126,  126,  126,    0,  126,  126,  126,  132,  132,
      132,    0,  132,  132,  132,  141,  141,  142,  142,  140,
      140,  140,  140,  140,  140,  140,  140,  140,  140,  140,

      140
    } ;

extern int phylipi_flex_debug;
int phylipi_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
static int yy_looking_for_trail_begin = 0;
static int yy_full_lp;
static int *yy_full_state;
#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up phylipitext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
(yy_lp) = (yy_full_lp); /* restore orig. accepting pos. */ \
(yy_state_ptr) = (yy_full_state); /* restore orig. state */ \
yy_current_state = *(yy_state_ptr); /* restore curr. state */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *phylipitext;
#line 1 "align/phylipil.l"
/* phylipil.l - PHYLIPI alignment lexer */
#line 4 "align/phylipil.l"
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#ifdef STDC_HEADERS
# include <stdlib.h>
# include <string.h>
#endif
#include <ctype.h>

#include "align/phylipiy.h"

static void clean_spc(char *str);
#define YY_NO_INPUT 1

#line 666 "align/phylipil.c"

#define INITIAL 0
#define HEAD 1
#define NAMS 2
#define SEQS 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int phylipilex_destroy (void );

int phylipiget_debug (void );

void phylipiset_debug (int debug_flag  );

YY_EXTRA_TYPE phylipiget_extra (void );

void phylipiset_extra (YY_EXTRA_TYPE user_defined  );

FILE *phylipiget_in (void );

void phylipiset_in  (FILE * _in_str  );

FILE *phylipiget_out (void );

void phylipiset_out  (FILE * _out_str  );

int phylipiget_leng (void );

char *phylipiget_text (void );

int phylipiget_lineno (void );

void phylipiset_lineno (int _line_number  );

YYSTYPE * phylipiget_lval (void );

void phylipiset_lval (YYSTYPE * yylval_param  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int phylipiwrap (void );
#else
extern int phylipiwrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( phylipitext, phylipileng, 1, phylipiout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( phylipiin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( phylipiin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, phylipiin))==0 && ferror(phylipiin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(phylipiin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int phylipilex \
               (YYSTYPE * yylval_param );

#define YY_DECL int phylipilex \
               (YYSTYPE * yylval_param )
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after phylipitext and phylipileng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( phylipileng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(phylipitext[phylipileng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
        YYSTYPE * yylval;
    
#line 41 "align/phylipil.l"


#line 867 "align/phylipil.c"

    yylval = yylval_param;

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)phylipialloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in phylipilex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! phylipiin )
			phylipiin = stdin;

		if ( ! phylipiout )
			phylipiout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			phylipiensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				phylipi_create_buffer(phylipiin,YY_BUF_SIZE );
		}

		phylipi_load_buffer_state( );
		}

	while (/*CONSTCOND*/ 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of phylipitext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 141 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_current_state != 140 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     (yy_looking_for_trail_begin) )
					{
					if ( yy_act == (yy_looking_for_trail_begin) )
						{
						(yy_looking_for_trail_begin) = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					(yy_looking_for_trail_begin) = yy_act & ~YY_TRAILING_MASK;
					(yy_looking_for_trail_begin) |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					(yy_full_match) = yy_cp;
					(yy_full_state) = (yy_state_ptr);
					(yy_full_lp) = (yy_lp);
					break;
					}
				++(yy_lp);
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 43 "align/phylipil.l"
; /* Empty lines ignored */
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 45 "align/phylipil.l"
{ BEGIN HEAD; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 46 "align/phylipil.l"
{ return INT; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 47 "align/phylipil.l"
{ return SPC; }
	YY_BREAK
case 5:
/* rule 5 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up phylipitext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up phylipitext again */
YY_RULE_SETUP
#line 48 "align/phylipil.l"
; /* Trailing spaces ignored */
	YY_BREAK
case 6:
/* rule 6 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up phylipitext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up phylipitext again */
YY_RULE_SETUP
#line 49 "align/phylipil.l"
; /* Extra stuff ignored */
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 50 "align/phylipil.l"
{ BEGIN NAMS; return EOL; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 51 "align/phylipil.l"
{ return ERR; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 53 "align/phylipil.l"
{ yylval->str = strdup(phylipitext); clean_spc(yylval->str);
                 if (*yylval->str == '\0') return ERR; return NAM; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 55 "align/phylipil.l"
{ yylval->str = strdup(phylipitext); return BAS; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 56 "align/phylipil.l"
; /* Sequence spaces ignored */
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 57 "align/phylipil.l"
{ return EOL; }
	YY_BREAK
case YY_STATE_EOF(NAMS):
#line 58 "align/phylipil.l"
{ BEGIN INITIAL; return EOL; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 59 "align/phylipil.l"
{ return ERR; }
	YY_BREAK
case 14:
/* rule 14 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up phylipitext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up phylipitext again */
YY_RULE_SETUP
#line 60 "align/phylipil.l"
{ BEGIN SEQS; return EOL; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 62 "align/phylipil.l"
{ yylval->str = strdup(phylipitext); return BAS; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 63 "align/phylipil.l"
; /* Sequence spaces/tabs ignored */
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 64 "align/phylipil.l"
{ return EOL; }
	YY_BREAK
case YY_STATE_EOF(SEQS):
#line 65 "align/phylipil.l"
{ BEGIN INITIAL; return EOL; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 66 "align/phylipil.l"
{ return ERR; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(HEAD):
#line 68 "align/phylipil.l"
{ return END; }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 69 "align/phylipil.l"
{ return ERR; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 70 "align/phylipil.l"
{ return ERR; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 72 "align/phylipil.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1118 "align/phylipil.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed phylipiin at a new source and called
			 * phylipilex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = phylipiin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( phylipiwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * phylipitext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of phylipilex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			phylipirestart(phylipiin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) phylipirealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 141 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 141 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 140);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					phylipirestart(phylipiin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( phylipiwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve phylipitext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void phylipirestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        phylipiensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            phylipi_create_buffer(phylipiin,YY_BUF_SIZE );
	}

	phylipi_init_buffer(YY_CURRENT_BUFFER,input_file );
	phylipi_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void phylipi_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		phylipipop_buffer_state();
	 *		phylipipush_buffer_state(new_buffer);
     */
	phylipiensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	phylipi_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (phylipiwrap()) processing, but the only time this flag
	 * is looked at is after phylipiwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void phylipi_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	phylipiin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE phylipi_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) phylipialloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in phylipi_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) phylipialloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in phylipi_create_buffer()" );

	b->yy_is_our_buffer = 1;

	phylipi_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with phylipi_create_buffer()
 * 
 */
    void phylipi_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		phylipifree((void *) b->yy_ch_buf  );

	phylipifree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a phylipirestart() or at EOF.
 */
    static void phylipi_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	phylipi_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then phylipi_init_buffer was _probably_
     * called from phylipirestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void phylipi_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		phylipi_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void phylipipush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	phylipiensure_buffer_stack();

	/* This block is copied from phylipi_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from phylipi_switch_to_buffer. */
	phylipi_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void phylipipop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	phylipi_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		phylipi_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void phylipiensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)phylipialloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in phylipiensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)phylipirealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in phylipiensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE phylipi_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) phylipialloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in phylipi_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	phylipi_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to phylipilex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       phylipi_scan_bytes() instead.
 */
YY_BUFFER_STATE phylipi_scan_string (yyconst char * yystr )
{
    
	return phylipi_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to phylipilex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE phylipi_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) phylipialloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in phylipi_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = phylipi_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in phylipi_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up phylipitext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		phylipitext[phylipileng] = (yy_hold_char); \
		(yy_c_buf_p) = phylipitext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		phylipileng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int phylipiget_lineno  (void)
{
        
    return phylipilineno;
}

/** Get the input stream.
 * 
 */
FILE *phylipiget_in  (void)
{
        return phylipiin;
}

/** Get the output stream.
 * 
 */
FILE *phylipiget_out  (void)
{
        return phylipiout;
}

/** Get the length of the current token.
 * 
 */
int phylipiget_leng  (void)
{
        return phylipileng;
}

/** Get the current token.
 * 
 */

char *phylipiget_text  (void)
{
        return phylipitext;
}

/** Set the current line number.
 * @param _line_number
 * 
 */
void phylipiset_lineno (int  _line_number )
{
    
    phylipilineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see phylipi_switch_to_buffer
 */
void phylipiset_in (FILE *  _in_str )
{
        phylipiin = _in_str ;
}

void phylipiset_out (FILE *  _out_str )
{
        phylipiout = _out_str ;
}

int phylipiget_debug  (void)
{
        return phylipi_flex_debug;
}

void phylipiset_debug (int  _bdebug )
{
        phylipi_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from phylipilex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    phylipiin = stdin;
    phylipiout = stdout;
#else
    phylipiin = (FILE *) 0;
    phylipiout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * phylipilex_init()
     */
    return 0;
}

/* phylipilex_destroy is for both reentrant and non-reentrant scanners. */
int phylipilex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		phylipi_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		phylipipop_buffer_state();
	}

	/* Destroy the stack itself. */
	phylipifree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    phylipifree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * phylipilex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *phylipialloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *phylipirealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void phylipifree (void * ptr )
{
	free( (char *) ptr );	/* see phylipirealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 72 "align/phylipil.l"




/* Clean trailing spaces ... */
static void clean_spc(char *str) {
  char *p;

  p = str;
  while (*p) { p++; }
  p--;
  while (p >= str && isspace((unsigned char)*p)) {
    *p = '\0'; p--; }

  return; }

